Name:           redland
Version:        1.0.12
Release:        1
Summary:        RDF Application Framework
Group:          System Environment/Libraries
License:        LGPLv2+ or ASL 2.0
URL:            http://librdf.org/
Source0:        http://download.librdf.org/source/%{name}-%{version}.tar.gz
Source1:        http://download.librdf.org/source/%{name}-%{version}.tar.gz.asc
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires:  db4-devel >= 4.7.25-2
BuildRequires:  raptor-devel >= 1.4.21-1
BuildRequires:  rasqal-devel >= 0.9.21-1
BuildRequires:  sqlite-devel >= 3.6.23.1-1
BuildRequires:  unixODBC-devel >= 2.2.14-2

Requires: db4 >= 4.7.25-2
Requires: raptor >= 1.4.21-1
Requires: rasqal >= 0.9.21-1
Requires: sqlite >= 3.6.23.1-1

%define _libdir64 %{_prefix}/lib64

%description
Redland is a library that provides a high-level interface for RDF
(Resource Description Framework) implemented in an object-based API.
It is modular and supports different RDF/XML parsers, storage
mechanisms and other elements. Redland is designed for applications
developers to provide RDF support in their applications as well as
for RDF developers to experiment with the technology.

The library is available as 32-bit and 64-bit.


%package        devel
Summary:        Libraries and header files for programs that use Redland
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       pkg-config
Requires:       raptor-devel >= 1.4.21-1
Requires:       rasqal-devel >= 0.9.21-1
Requires:       sqlite-devel >= 3.6.23.1-1
Requires:       unixODBC-devel >= 2.2.14-2

%description    devel
Header files for development with Redland.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "cc -q64" or "gcc -maix64".


%package        virtuoso
Summary:        Virtuoso storage support for Redland
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       unixODBC >= 2.2.14-2

%description    virtuoso
This package provides Redland's storage support for graphs in memory and
persistently with Virtuoso files or URIs.


%prep
%setup -q
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cp -r 32bit/* 64bit/


%build
export CC="xlc_r"

cd 64bit
# first build the 64-bit version
export OBJECT_MODE=64
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
  --prefix=%{_prefix} \
  --libdir=%{_libdir64} \
  --mandir=%{_mandir} \
  --enable-shared --disable-static \
  --enable-release \
  --with-included-ltdl=no
make %{?_smp_mflags}

cd ../32bit
# now build the 32-bit version
export OBJECT_MODE=32
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
  --prefix=%{_prefix} \
  --mandir=%{_mandir} \
  --enable-shared --disable-static \
  --enable-release \
  --with-included-ltdl=no
make %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
gmake DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in * ; do
    mv -f ${f} ${f}_64
  done
)

cd ../32bit
export OBJECT_MODE=32
gmake DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done
  cd %{name}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
  cd %{name}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared libraries containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/librdf.a ${RPM_BUILD_ROOT}%{_libdir64}/librdf.so.0

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc 32bit/AUTHORS 32bit/COPYING 32bit/COPYING.LIB 32bit/LICENSE.txt 32bit/NEWS
%doc 32bit/README 32bit/LICENSE-2.0.txt 32bit/NOTICE 32bit/TODO
%doc 32bit/FAQS.html 32bit/LICENSE.html 32bit/NEWS.html 32bit/README.html
%doc 32bit/TODO.html
%{_bindir}/rdfproc*
%{_bindir}/redland-db-upgrade*
%{_libdir}/*.a
%{_libdir}/*.so*
%{_libdir64}/*.so*
%dir %{_libdir}/%{name}
%dir %{_libdir64}/%{name}
%{_libdir}/%{name}/librdf_storage_sqlite.so
%{_libdir64}/%{name}/librdf_storage_sqlite.so
%{_mandir}/man1/redland-db-upgrade.1
%{_mandir}/man1/rdfproc.1
%{_mandir}/man3/redland.3
%dir %{_datadir}/%{name}
/usr/bin/rdfproc*
/usr/bin/redland-db-upgrade*
/usr/lib/*.a
/usr/lib/*.so*
/usr/lib64/*.so*


%files virtuoso
%defattr(-,root,system,-)
%{_libdir}/%{name}/librdf_storage_virtuoso.so
%{_libdir64}/%{name}/librdf_storage_virtuoso.so


%files devel
%defattr(-,root,system,-)
%doc 32bit/ChangeLog 32bit/RELEASE.html
%{_bindir}/redland-config*
%{_includedir}/*
%{_mandir}/man1/redland-config.1
%{_datadir}/%{name}/Redland.i
%{_datadir}/gtk-doc/
%{_libdir}/*.la
%{_libdir64}/*.la
%{_libdir}/pkgconfig/*.pc
%{_libdir64}/pkgconfig/*.pc
%{_libdir}/%{name}/*.la
%{_libdir64}/%{name}/*.la
/usr/bin/redland-config*
/usr/include/*
/usr/lib/*.la
/usr/lib64/*.la


%changelog
* Thu Jan 13 2011 Michael Perzl <michael@perzl.org> - 1.0.12-1
- first version for AIX V5.1 and higher
